# handyderivatives

## Running it
`python handyderivatives.py functions.txt`

## How to use it
It gets the derivatives for differentiable functions of a single variable.

Edit a config file that looks like this. 

![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/file.png)

To get output that looks like this. LaTex output is included.

![Placeholder](https://raw.githubusercontent.com/Fitzy1293/handyderivatives/main/output.png)
